OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Не може да зе запишува во \"config\" директориумот!",
    "This can usually be fixed by giving the web server write access to the config directory." : "Ова најчесто се поправа со давање на дозвола веб серверот за запишување во config папката.",
    "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Но, доколку претпочитувате config.php да биде само за читање, поставете параметар \"config_is_read_only\" во него.",
    "See %s" : "Види %s",
    "Sample configuration detected" : "Детектирана е едноставна конфигурација",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Детектирано е дека едноставната конфигурација е копирана. Ова може да и наштети на вашата инсталација и не е поддржано. Прочитајте ја документацијата пред да правите промени во config.php",
    "The page could not be found on the server." : "Страницата не е пронајдена на серверот.",
    "%s email verification" : "%s е-пошта верификација",
    "Email verification" : "Е-пошта верификација",
    "Click the following button to confirm your email." : "Кликнете на следното копче за да ја потврдите вашата е-пошта адреса.",
    "Click the following link to confirm your email." : "Кликнете на следниот линк за да ја потврдите вашата е-пошта адреса.",
    "Confirm your email" : "Потврдите ја вашата е-пошта",
    "Other activities" : "Други активности",
    "%1$s and %2$s" : "%1$s и %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s и %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s и %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s и %5$s",
    "Enterprise bundle" : "Професионален пакет",
    "Groupware bundle" : "Пакет со групни производи",
    "Hub bundle" : "Централизиран пакет",
    "Social sharing bundle" : "Пакет за споделување на социјални мрежи",
    "PHP %s or higher is required." : "Потребно е PHP верзија %s или повисока.",
    "PHP with a version lower than %s is required." : "Потебна е PHP верзија пониска од %s.",
    "%sbit or higher PHP required." : "%sили повисока верзија на PHP е потребно.",
    "The following architectures are supported: %s" : "Следниве архитектури се поддржани: %s",
    "The following databases are supported: %s" : "Следниве бази со податоци се поддржани: %s",
    "The command line tool %s could not be found" : "Алатка %s за командна линија, не е пронајдена",
    "The library %s is not available." : "Библиотеката %s не е достапна.",
    "Library %1$s with a version higher than %2$s is required - available version %3$s." : "Потребна е библиотека %1$s со повисока верзија од %2$s - достапна верзија %3$s.",
    "Library %1$s with a version lower than %2$s is required - available version %3$s." : "Потебна е библиотека %1$s со пониска верзија од %2$s - достапна верзија %3$s.",
    "The following platforms are supported: %s" : "Следниве платформи се поддржани: %s",
    "Server version %s or higher is required." : "Потребна е верзија %s или поголема на серверот.",
    "Server version %s or lower is required." : "Потербна е верзија %s или помала на серверот.",
    "Wiping of device %s has started" : "Започна бришење на уредот %s",
    "Wiping of device »%s« has started" : "Започна бришење на уредот »%s«",
    "»%s« started remote wipe" : "Запошна далечинско бришење на уредот »%s«",
    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "Започна бришење на уредот »%s« започна процес на далечинско бришење. Ќе добиете друга порака кога процесот ќе биде завршен",
    "Wiping of device %s has finished" : "Бришењето на уредот %s е завршено",
    "Wiping of device »%s« has finished" : "Бришењето на уредот »%s« е завршено",
    "»%s« finished remote wipe" : "Заврши далечинското бришење на уредот »%s«",
    "Device or application »%s« has finished the remote wipe process." : "Заврши процесот на далечинско бришење на уредот или апликацијата »%s«.",
    "Remote wipe started" : "Започна далечинското бришење",
    "A remote wipe was started on device %s" : "Започна далечинско бришење на уредот %s",
    "Remote wipe finished" : "Заврши далечинското бришење",
    "The remote wipe on %s has finished" : "Далечинското бришење на %s заврши",
    "Authentication" : "Автентикација",
    "Unknown filetype" : "Непознат тип на датотека",
    "Invalid image" : "Невалидна фотографија",
    "Avatar image is not square" : "Сликата за Аватар не е квадратна",
    "Files" : "Датотеки",
    "View profile" : "Прегледај профил",
    "Local time: %s" : "Локално време: %s",
    "today" : "денес",
    "tomorrow" : "утре",
    "yesterday" : "вчера",
    "_in %n day_::_in %n days_" : ["за 1 ден","за %n дена"],
    "_%n day ago_::_%n days ago_" : ["пред 1 ден","пред %n дена"],
    "next month" : "следниот месец",
    "last month" : "предходниот месец",
    "_in %n month_::_in %n months_" : ["за %n месец","за %n месеца"],
    "_%n month ago_::_%n months ago_" : ["пред %n месец","пред %n месеци"],
    "next year" : "следниот месец",
    "last year" : "предходната година",
    "_in %n year_::_in %n years_" : ["за 1 година","за %n години"],
    "_%n year ago_::_%n years ago_" : ["пред 1 година","пред %n години"],
    "_in %n hour_::_in %n hours_" : ["за 1 час","за %n часа"],
    "_%n hour ago_::_%n hours ago_" : ["пред 1 час","пред %n часа"],
    "_in %n minute_::_in %n minutes_" : ["за 1 минута","за %n минути"],
    "_%n minute ago_::_%n minutes ago_" : ["пред 1 минута","пред %n минути"],
    "in a few seconds" : "за неколку секунди",
    "seconds ago" : "пред неколку секунди",
    "Empty file" : "Празна датотека",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Модул со ИД: %s не постои. Овозможете го во параметрите на апликациите или контактирајте администратор.",
    "Dot files are not allowed" : "Датотеки само со точки не се дозволени",
    "File already exists" : "Датотека веќе постои",
    "Invalid path" : "Невалидна патека",
    "Failed to create file from template" : "Неуспешно креирање на датотека од шаблон",
    "Templates" : "Шаблони",
    "Filename contains at least one invalid character" : "Името на датотеката соджи невалиден карактер",
    "Empty filename is not allowed" : "Датотеки без име не се дозволени",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "Апликацијата \"%s\" неможе да се инсталира бидејќи датотеката appinfo неможе да се прочита.",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Апликацијата \"%s\" неможе да се инсталира бидејќи не е компатибилна со верзијата на серверот.",
    "__language_name__" : "Македонски",
    "This is an automatically sent email, please do not reply." : "Ова е автоматски испратена порака, не одговарајте на истата.",
    "Appearance and accessibility" : "Изглед и пристапност",
    "Apps" : "Аппликации",
    "Personal settings" : "Лични параметри",
    "Administration settings" : "Административни параметри",
    "Settings" : "Параметри",
    "Log out" : "Одјава",
    "Accounts" : "Сметки",
    "Email" : "Е-пошта",
    "Mail %s" : "Пошта %s",
    "Fediverse" : "Федиверс",
    "View %s on the fediverse" : "Погледни %s на федиверс",
    "Phone" : "Телефон",
    "Call %s" : "Повикај %s",
    "Twitter" : "Twitter",
    "View %s on Twitter" : "Погледни %s на Twitter",
    "Website" : "Веб страна",
    "Visit %s" : "Посети %s",
    "Address" : "Адреса",
    "Profile picture" : "Фотографија",
    "About" : "За",
    "Display name" : "Име и презиме",
    "Headline" : "Наслов",
    "Organisation" : "Организација",
    "Role" : "Улога",
    "Additional settings" : "Дополнителни параметри",
    "Enter the database name for %s" : "Внесете го името на базата за %s",
    "You cannot use dots in the database name %s" : "Не можеш да користиш точки во името на базата %s",
    "You need to enter details of an existing account." : "Потребно е да внесете детали од постоечката сметка.",
    "Oracle connection could not be established" : "Oracle врската неможе да се воспостави",
    "For the best results, please consider using a GNU/Linux server instead." : "За најдобри резултати, размислете за користење на сервер со GNU/Linux.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Највероватно оваа истанца %s е стартувана на 32-битна PHP средина и open_basedir е конфигурано во php.ini. Ова ќе прави проблеми со датотеки поголеми од 4 GB.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Отстранете го параметарот open_basedir од php.ini или преминете на 64-битна PHP средина.",
    "Set an admin password." : "Постави администраторска лозинка.",
    "Cannot create or write into the data directory %s" : "Неможете да креирате или да запишувате во папката за податоци %s",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "За позадинското споделување %s мора се имплементира интерфејсот OCP\\Share_Backend",
    "Sharing backend %s not found" : "Не е пронајдено позадинско споделување %s",
    "Sharing backend for %s not found" : "Не е пронајдено позадинско споделување за %s.",
    "%1$s via %2$s" : "%1$s преку %2$s",
    "Unknown share type" : "Непознат вид на споделување",
    "You are not allowed to share %s" : "Не сте овластени да ја споделите %s",
    "Cannot increase permissions of %s" : "Неможат да се зголемат дозволите на %s",
    "Files cannot be shared with delete permissions" : "Датотеки неможат да бидат споделени со дозвола за бришење",
    "Files cannot be shared with create permissions" : "Датотеки неможат да бидат споделени со дозвола за создавање",
    "Expiration date is in the past" : "Рокот на траење е во минато време",
    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Неможе да се постави рок на траење повеќе од 1 ден","Неможе да се постави рок на траење повеќе од %s дена"],
    "Sharing is only allowed with group members" : "Споделувањето е овозможено само со членови на групата",
    "The requested share does not exist anymore" : "Споделувањето не постои повеќе",
    "The user was not created because the user limit has been reached. Check your notifications to learn more." : "Корисникот не е креиран затоа што максималниот број на корисници е достигнат. Проверете ги вашите известувања за да дознаете повеќе.",
    "Could not find category \"%s\"" : "Не можам да најдам категорија „%s“",
    "Sunday" : "Недела",
    "Monday" : "Понеделник",
    "Tuesday" : "Вторник",
    "Wednesday" : "Среда",
    "Thursday" : "Четврток",
    "Friday" : "Петок",
    "Saturday" : "Сабота",
    "Sun." : "Нед.",
    "Mon." : "Пон.",
    "Tue." : "Вто.",
    "Wed." : "Сре.",
    "Thu." : "Чет.",
    "Fri." : "Пет.",
    "Sat." : "Саб.",
    "Su" : "Не",
    "Mo" : "По",
    "Tu" : "Вт",
    "We" : "Ср",
    "Th" : "Че",
    "Fr" : "Пе",
    "Sa" : "Са",
    "January" : "Јануари",
    "February" : "Февруари",
    "March" : "Март",
    "April" : "Април",
    "May" : "Мај",
    "June" : "Јуни",
    "July" : "Јули",
    "August" : "Август",
    "September" : "Септември",
    "October" : "Октомври",
    "November" : "Ноември",
    "December" : "Декември",
    "Jan." : "Јан.",
    "Feb." : "Фев.",
    "Mar." : "Мар.",
    "Apr." : "Апр.",
    "May." : "Мај.",
    "Jun." : "Јун.",
    "Jul." : "Јул.",
    "Aug." : "Авг.",
    "Sep." : "Сеп.",
    "Oct." : "Окт.",
    "Nov." : "Ное.",
    "Dec." : "Дек.",
    "A valid password must be provided" : "Мора да се обезбеди валидна лозинка",
    "Login canceled by app" : "Најавата е одкажана од апликација",
    "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Апликацијата \"%1$s\" не може да се инсталира затоа што следниве зависности не се исполнети: %2$s",
    "a safe home for all your data" : "безбеден дом за сите ваши податоци",
    "Application is not enabled" : "Апликацијата не е овозможена",
    "Authentication error" : "Грешка во автентикација",
    "Token expired. Please reload page." : "Жетонот е истечен. Ве молам превчитајте ја страницата.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Нема инсталирано додаток за (sqlite, mysql, или postgresql) база на податоци.",
    "Cannot write into \"config\" directory." : "Не може да зе запишува во \"config\" директориумот",
    "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Ова најчесто се поправа со давање дозвола на веб серверот за запишување во config папката. Видете %s",
    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Или, доколку претпочитувате config.php да биде само за читање, поставете параметар \"config_is_read_only\" во него. Видете %s",
    "Cannot write into \"apps\" directory." : "Не може да зе запишува во \"apps\" директориумот",
    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Ова најчесто се поправа со давање дозвола на веб серверот за запишување во папката со апликации или оневозможување на продавницата за апликации во кофигурациската датотека.",
    "Cannot create \"data\" directory." : "Неможе да се креира директориум \"data\"",
    "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Ова најчесто се поправа со давање дозвола на веб серверот за запишување во главната папка. Видете %s",
    "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Дозволите најчесто се поправаат со давање дозвола на веб серверот за запишување во главната папка. Видете %s",
    "Your data directory is not writable." : "Во Вашата папка со податоци неможе да се запишува.",
    "Setting locale to %s failed." : "Неуспешно поставување на локацијата %s ",
    "Please install one of these locales on your system and restart your web server." : "Инсталирајте една од овие локациски податоци во вашиот систем и рестартирајте го веб серверот.",
    "PHP module %s not installed." : "PHP модулот %s не е инсталиран.",
    "Please ask your server administrator to install the module." : "Замолете го сервер администраторот да го инсталира додатокот.",
    "PHP setting \"%s\" is not set to \"%s\"." : "PHP поставката \"%s\" не е поставена до \"%s\".",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "Прилагодувањето на оваа поставка во php.ini ќе направи повторно да работи ",
    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> е поставено на <code>%s</code> очекувана вредност е <code>0</code>.",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "За да го поправите ова, поставете вредност за <code>mbstring.func_overload</code> = <code>0</code> во вашата php.ini датотека.",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP поставено да ги поставува во линија внатрешните блокови на документите. Ова ќе ги направи неколку основни апликации недостапни.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Ова е веројатно предизвикано од кеш-меморија/забрзување како што се Zend OPcache или eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "PHP модулот е инсталиран, но сеуште се прикажува како да недостасува?",
    "Please ask your server administrator to restart the web server." : "Замолете го сервер администраторот да го рестартира веб серверот.",
    "The required %s config variable is not configured in the config.php file." : "Потребната променлива %s не е конфигурирана config.php датотеката.",
    "Please ask your server administrator to check the Nextcloud configuration." : "Замолете го сервер администраторот да ја провери конфигурацијата.",
    "Your data directory must be an absolute path." : "Вашата папка со податоци мора да биде апсолутна патека.",
    "Check the value of \"datadirectory\" in your configuration." : "Проверете ја вредноста на \"datadirectory\" во вашата конфигурација.",
    "Your data directory is invalid." : "Вашата папка со податоци не е валидна.",
    "Action \"%s\" not supported or implemented." : "Акцијата \"%s\" не е поддржана или не е имплементирана.",
    "Authentication failed, wrong token or provider ID given" : "Неуспешна автентификација, погрешен токен или зададен погрешен ИД",
    "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Некој параметри недостасуваат за да се комплетира барањето.Параметри шо недостасуваат: \"%s\"",
    "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "ИД \"%1$s\" веќе се користи од друг федерален Cloud провајдер \"%2$s\"",
    "Cloud Federation Provider with ID: \"%s\" does not exist." : "Федерален Cloud провајдер со ИД: \"%s\" не постои.",
    "Could not obtain lock type %d on \"%s\"." : "Не може да се користи тип на заклучување %d на \"%s\".",
    "Storage unauthorized. %s" : "Неавторизирано складиште. %s",
    "Storage incomplete configuration. %s" : "Конфигурацијата на складиштето не е комплетна. %s",
    "Storage connection error. %s" : "Грешка во конекција до складиштето. %s",
    "Storage is temporarily not available" : "Складиштето моментално не е достапно",
    "Storage connection timeout. %s" : "Поврзувањето со складиштето не успеа. %s",
    "Text" : "Текст",
    "Summary" : "Резиме",
    "Translate" : "Преведи",
    "Generate headline" : "Генерирај заглавие",
    "Education Edition" : "Едукативно издание",
    "File name is a reserved word" : "Името на датотеката е резервиран збор",
    "File name contains at least one invalid character" : "Името на датотеката соджи невалиден карактер",
    "File name is too long" : "Името на датотеката е премногу долго",
    "Users" : "Корисници",
    "%1$s shared »%2$s« with you and wants to add:" : "%1$s ја сподели папката »%2$s« и додаде:",
    "%1$s shared »%2$s« with you and wants to add" : "%1$s ја сподели папката »%2$s« и додаде",
    "»%s« added a note to a file shared with you" : "»%s« додаде белешка до датотеката што ја сподели со вас",
    "Open »%s«" : "Отвори »%s«",
    "%1$s shared »%2$s« with you" : "%1$s сподели »%2$s« со вас",
    "%1$s shared »%2$s« with you." : "%1$s сподели »%2$s« со вас.",
    "Click the button below to open it." : "Кликнете на копчето подолу за да ја отворите.",
    "File is currently busy, please try again later" : "Датотеката моментално е зафатена, обидете се повторно",
    "Cannot download file" : "Не може да се преземе датотеката",
    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Осигурете се дека има датотека наречена \".ocdata\" во главната папка со податоци."
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
